library(igraph)

shinyServer(
  function(input, output) {

    # read and cache the graph
    inputGraph = reactive({
      inFile = input$graph
      if (!is.null(inFile))
        read.graph(file=inFile$datapath, format=input$format)
    })

    # read and cache the layout
    # inputCoords = reactive({layout.auto(inputGraph())});
    inputCoords = reactive({layout.fruchterman.reingold(inputGraph())});
    # render the plot
    output$net = renderPlot({
      # viualize button
      input$plot
      # isolate input graph
      g = isolate(inputGraph())
      
      if (!is.null(g)) {      
        # isolate layout
        coords = isolate(inputCoords())
        # isolate community structure
        cty = isolate(switch(input$community, 
                      "leading eigenvector" = leading.eigenvector.community(g),
                      "greedy" = fastgreedy.community(g),
                      "edge betweenness" = edge.betweenness.community(g),
                      "walktrap" = walktrap.community(g),
                      "spinglass" = spinglass.community(g),
                      "label propagation" = label.propagation.community(g),
                      "infomap" = infomap.community(g),
                      "multilevel" = multilevel.community(g),
                      "optimal" = optimal.community(g),
                      ))
        
        smart.lab = paste("Modularity:", round(modularity(cty), 3))
        plot(cty, g, layout=coords, vertex.label=NA, vertex.size = 5, xlab=smart.lab)
      }      
    })
  }
)